==> jsbos-common-2024.12.dev.005-sources.jar: com/bringspring/common/util/enums/FileTypeEnum.java <==
package com.bringspring.common.util.enums;

/**
 * @author RKKJ开发平台组
 * @version V1.0.0
 * @copyright 荣科科技股份有限公司
 * @date 2021/3/16 10:51
 */
public class FileTypeEnum {
    /**
     * 临时文件存储路径
     */
    public static final String LICENSE="license";
    /**
     * 用户头像存储路径
     */
    public static final String USERAVATAR = "useravatar";
    /**
     * 邮件文件存储路径
     */
    public static final String MAIL = "mail";
    /**
     * IM聊天图片+语音存储路径
     */
    public static final String IM = "im";
    /**
     * 临时文件存储路径
     */
    public static final String WEIXIN = "weixin";
    /**
     *临时文件存储路径
     */
    public static final String WORKFLOW="workflow";
    /**
     *前端附件文件目录
     */
    public static final String ANNEX="annex";
    public static final String ANNEXPIC="annexpic";
    /**
     *数据库备份文件路径
     */
    public static final String DATABACKUP="dataBackup";
    /**
     *文档管理存储路径
     */
    public static final String DOCUMENT="document";
    /**
     *文件夹压缩下载存储路径
     */
    public static final String DOCUMENTZIP="documentzip";
    /**
     *临时文件存储路径
     */
    public static final String TEMPORARY="temporary";
    /**
     *允许上传文件类型
     */
    public static final String ALLOWUPLOADFILETYPE="allowuploadfiletype";
    /**
     *文件在线预览存储pdf
     */
    public static final String DOCUMENTPREVIEWPATH="preview";
    /**
     *文件模板存储路径
     */
    public static final String TEMPLATEFILE="templatefile";
    /**
     *前端文件目录
     */
    public static final String SERVICEDIRECTORY="servicedirectory";
    /**
     *后端文件目录
     */
    public static final String WEBDIRECTORY="webdirectory";
    /**
     * 代码生成器生成位置
     */
    public static final String CODETEMP = "codetemp";
    /**
     * 大屏路径
     */
    public static final String BIVISUALPATH = "bivisualpath";
    /**
     * 导出
     */
    public static final String EXPORT = "export";

    /**
     * 边缘计算文件存储
     */
    public static final String DOCUMENTECBP = "documentecbp";
    /**
     * 物联网解析包
     */
    public static final String IOTANALYSIS = "iotanalysis";

}

==> jsbos-common-2025.12.02-dev-sources.jar: com/bringspring/common/util/enums/FileTypeEnum.java <==
package com.bringspring.common.util.enums;

/**
 * @author RKKJ开发平台组
 * @version V1.0.0
 * @copyright 荣科科技股份有限公司
 * @date 2021/3/16 10:51
 */
public class FileTypeEnum {
    /**
     * 临时文件存储路径
     */
    public static final String LICENSE="license";
    /**
     * 用户头像存储路径
     */
    public static final String USERAVATAR = "useravatar";
    /**
     * 邮件文件存储路径
     */
    public static final String MAIL = "mail";
    /**
     * IM聊天图片+语音存储路径
     */
    public static final String IM = "im";
    /**
     * 临时文件存储路径
     */
    public static final String WEIXIN = "weixin";
    /**
     *临时文件存储路径
     */
    public static final String WORKFLOW="workflow";
    /**
     *前端附件文件目录
     */
    public static final String ANNEX="annex";

    /**
     * 费控原始文件目录
     */
    public static final String ECSORIGINAL="ecsoriginal";

    /*
     * 费控报销单目录
     */
    public static final String ECSREIMBURSEMENT="ecsreimbursement";


    public static final String ANNEXPIC="annexpic";
    /**
     *数据库备份文件路径
     */
    public static final String DATABACKUP="dataBackup";
    /**
     *文档管理存储路径
     */
    public static final String DOCUMENT="document";
    /**
     *文件夹压缩下载存储路径
     */
    public static final String DOCUMENTZIP="documentzip";
    /**
     *临时文件存储路径
     */
    public static final String TEMPORARY="temporary";
    /**
     *允许上传文件类型
     */
    public static final String ALLOWUPLOADFILETYPE="allowuploadfiletype";
    /**
     *文件在线预览存储pdf
     */
    public static final String DOCUMENTPREVIEWPATH="preview";
    /**
     *文件模板存储路径
     */
    public static final String TEMPLATEFILE="templatefile";
    /**
     *前端文件目录
     */
    public static final String SERVICEDIRECTORY="servicedirectory";
    /**
     *后端文件目录
     */
    public static final String WEBDIRECTORY="webdirectory";
    /**
     * 代码生成器生成位置
     */
    public static final String CODETEMP = "codetemp";
    /**
     * 大屏路径
     */
    public static final String BIVISUALPATH = "bivisualpath";
    /**
     * 导出
     */
    public static final String EXPORT = "export";

    /**
     * 边缘计算文件存储
     */
    public static final String DOCUMENTECBP = "documentecbp";
    /**
     * 物联网解析包
     */
    public static final String IOTANALYSIS = "iotanalysis";

}
